@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Mapping::Simple;
@@ -19,15 +19,9 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::GenericInterface::Mapping::Simple - GenericInterface simple data mapping backend
 
-=head1 SYNOPSIS
-
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Mapping->new();
@@ -77,7 +71,7 @@ sub new {
     return $Self;
 }
 
-=item Map()
+=head2 Map()
 
 provides 1:1 and regex mapping for keys and values
 also the use of a default for keys and values that were not mapped is possible
@@ -245,7 +239,7 @@ sub Map {
         # check if we have a value mapping for the specific key
         my $ValueMap;
         if ( $Config->{ValueMap} && $Config->{ValueMap}->{$NewKey} ) {
-            $ValueMap = $Config->{ValueMap}->{$NewKey};
+            $ValueMap = $Config->{ValueMap}->{$NewKey}
         }
 
         if ($ValueMap) {
@@ -293,7 +287,7 @@ sub Map {
 
 =begin Internal:
 
-=item _ConfigCheck()
+=head2 _ConfigCheck()
 
 does checks to make sure the config is sane
 
@@ -470,14 +464,12 @@ sub _ConfigCheck {
 
 =end Internal:
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
