@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminDynamicFieldDateTime;
@@ -28,6 +28,13 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # Store last entity screen.
+    $Kernel::OM->Get('Kernel::System::AuthSession')->UpdateSessionID(
+        SessionID => $Self->{SessionID},
+        Key       => 'LastScreenEntity',
+        Value     => $Self->{RequestedURL},
+    );
+
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     if ( $Self->{Subaction} eq 'Add' ) {
@@ -79,9 +86,9 @@ sub _Add {
     }
 
     # get the object type and field type display name
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    my $ObjectTypeName
-        = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName} || '';
+    my $ConfigObject   = $Kernel::OM->Get('Kernel::Config');
+    my $ObjectTypeName = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName}
+        || '';
     my $FieldTypeName = $ConfigObject->Get('DynamicFields::Driver')->{ $GetParam{FieldType} }->{DisplayName} || '';
 
     return $Self->_ShowScreen(
@@ -126,7 +133,7 @@ sub _AddAction {
             $DynamicFieldObject->DynamicFieldList(
                 Valid      => 0,
                 ResultType => 'HASH',
-            )
+                )
         };
 
         %DynamicFieldsList = reverse %DynamicFieldsList;
@@ -240,9 +247,9 @@ sub _Change {
     }
 
     # get the object type and field type display name
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    my $ObjectTypeName
-        = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName} || '';
+    my $ConfigObject   = $Kernel::OM->Get('Kernel::Config');
+    my $ObjectTypeName = $ConfigObject->Get('DynamicFields::ObjectType')->{ $GetParam{ObjectType} }->{DisplayName}
+        || '';
     my $FieldTypeName = $ConfigObject->Get('DynamicFields::Driver')->{ $GetParam{FieldType} }->{DisplayName} || '';
 
     my $FieldID = $ParamObject->GetParam( Param => 'ID' );
@@ -340,7 +347,7 @@ sub _ChangeAction {
             $DynamicFieldObject->DynamicFieldList(
                 Valid      => 0,
                 ResultType => 'HASH',
-            )
+                )
         };
 
         %DynamicFieldsList = reverse %DynamicFieldsList;
@@ -421,6 +428,34 @@ sub _ChangeAction {
         );
     }
 
+    # Check if dynamic field is present in SysConfig setting
+    my $UpdateEntity        = $ParamObject->GetParam( Param => 'UpdateEntity' ) || '';
+    my $SysConfigObject     = $Kernel::OM->Get('Kernel::System::SysConfig');
+    my %DynamicFieldOldData = %{$DynamicFieldData};
+    my @IsDynamicFieldInSysConfig;
+    @IsDynamicFieldInSysConfig = $SysConfigObject->ConfigurationEntityCheck(
+        EntityType => 'DynamicField',
+        EntityName => $DynamicFieldData->{Name},
+    );
+    if (@IsDynamicFieldInSysConfig) {
+
+        # An entity present in SysConfig couldn't be invalidated.
+        if (
+            $Kernel::OM->Get('Kernel::System::Valid')->ValidLookup( ValidID => $GetParam{ValidID} )
+            ne 'valid'
+            )
+        {
+            $Errors{ValidIDInvalid}         = 'ServerError';
+            $Errors{ValidOptionServerError} = 'InSetting';
+        }
+
+        # In case changing name an authorization (UpdateEntity) should be send
+        elsif ( $DynamicFieldData->{Name} ne $GetParam{Name} && !$UpdateEntity ) {
+            $Errors{NameInvalid}              = 'ServerError';
+            $Errors{InSettingNameServerError} = 1;
+        }
+    }
+
     # return to change screen if errors occured
     if (%Errors) {
         return $Self->_ShowScreen(
@@ -462,9 +497,60 @@ sub _ChangeAction {
         );
     }
 
-    return $LayoutObject->Redirect(
-        OP => "Action=AdminDynamicField",
-    );
+    if (
+        @IsDynamicFieldInSysConfig
+        && $DynamicFieldOldData{Name} ne $GetParam{Name}
+        && $UpdateEntity
+        )
+    {
+        SETTING:
+        for my $SettingName (@IsDynamicFieldInSysConfig) {
+
+            my %Setting = $SysConfigObject->SettingGet(
+                Name => $SettingName,
+            );
+
+            next SETTING if !IsHashRefWithData( \%Setting );
+
+            $Setting{EffectiveValue} =~ s/$DynamicFieldOldData{Name}/$GetParam{Name}/g;
+
+            my $ExclusiveLockGUID = $SysConfigObject->SettingLock(
+                Name   => $Setting{Name},
+                Force  => 1,
+                UserID => $Self->{UserID}
+            );
+            $Setting{ExclusiveLockGUID} = $ExclusiveLockGUID;
+
+            my %UpdateSuccess = $SysConfigObject->SettingUpdate(
+                %Setting,
+                UserID => $Self->{UserID},
+            );
+        }
+
+        $SysConfigObject->ConfigurationDeploy(
+            Comments      => "DynamicField name change",
+            DirtySettings => \@IsDynamicFieldInSysConfig,
+            UserID        => $Self->{UserID},
+            Force         => 1,
+        );
+    }
+
+    # if the user would like to continue editing the dynamic field, just redirect to the change screen
+    if (
+        defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
+        && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
+        )
+    {
+        return $LayoutObject->Redirect(
+            OP =>
+                "Action=$Self->{Action};Subaction=Change;ObjectType=$DynamicFieldData->{ObjectType};FieldType=$DynamicFieldData->{FieldType};ID=$FieldID"
+        );
+    }
+    else {
+
+        # otherwise return to overview
+        return $LayoutObject->Redirect( OP => "Action=AdminDynamicField" );
+    }
 }
 
 sub _ShowScreen {
@@ -499,7 +585,7 @@ sub _ShowScreen {
     # when adding we need to create an extra order number for the new field
     if ( $Param{Mode} eq 'Add' ) {
 
-        # get the last element form the order list and add 1
+        # get the last element from the order list and add 1
         my $LastOrderNumber = $DynamicfieldOrderList[-1];
         $LastOrderNumber++;
 
@@ -515,7 +601,7 @@ sub _ShowScreen {
         if ( $DynamicfieldNamesList{$OrderNumber} && $OrderNumber ne $Param{FieldOrder} ) {
             $OrderNamesList{$OrderNumber} = $OrderNumber . ' - '
                 . $CurrentlyText
-                . $DynamicfieldNamesList{$OrderNumber};
+                . $DynamicfieldNamesList{$OrderNumber}
         }
     }
 
@@ -611,6 +697,51 @@ sub _ShowScreen {
         $ReadonlyInternalField = 'readonly="readonly"';
     }
 
+    my $DynamicFieldName = $Param{Name};
+
+    # Add warning in case the DynamicField belongs a SysConfig setting.
+    my $SysConfigObject = $Kernel::OM->Get('Kernel::System::SysConfig');
+
+    # In case dirty setting disable form
+    my $IsDirtyConfig = 0;
+    my @IsDirtyResult = $SysConfigObject->ConfigurationDirtySettingsList();
+    my %IsDirtyList   = map { $_ => 1 } @IsDirtyResult;
+
+    my @IsDynamicFieldInSysConfig = $SysConfigObject->ConfigurationEntityCheck(
+        EntityType => 'DynamicField',
+        EntityName => $DynamicFieldName // '',
+    );
+
+    if (@IsDynamicFieldInSysConfig) {
+        $LayoutObject->Block(
+            Name => 'DynamicFieldInSysConfig',
+            Data => {
+                OldName => $DynamicFieldName,
+            },
+        );
+        for my $SettingName (@IsDynamicFieldInSysConfig) {
+            $LayoutObject->Block(
+                Name => 'DynamicFieldInSysConfigRow',
+                Data => {
+                    SettingName => $SettingName,
+                },
+            );
+
+            # Verify if dirty setting
+            if ( $IsDirtyList{$SettingName} ) {
+                $IsDirtyConfig = 1;
+            }
+
+        }
+    }
+
+    if ($IsDirtyConfig) {
+        $LayoutObject->Block(
+            Name => 'DynamicFieldInSysConfigDirty',
+            ,
+        );
+    }
+
     # generate output
     $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminDynamicFieldDateTime',
@@ -627,11 +758,12 @@ sub _ShowScreen {
             ReadonlyInternalField => $ReadonlyInternalField,
             Link                  => $Link,
             LinkPreview           => $LinkPreview,
-        }
+            }
     );
 
     $Output .= $LayoutObject->Footer();
 
     return $Output;
 }
+
 1;
