@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminProcessManagement;
@@ -111,21 +111,6 @@ sub Run {
                         $BackendName,
                     );
 
-                    my %DependencyCheck = $BackendPre->DependencyCheck();
-
-                    if ( !$DependencyCheck{Success} && $DependencyCheck{ErrorMessage} ) {
-
-                        return $Self->_ShowOverview(
-                            NotifyData => [
-                                {
-                                    Priority => 'Notice',
-                                    Data     => $DependencyCheck{ErrorMessage},
-                                },
-                            ],
-                            %Param,
-                        );
-                    }
-
                     my %Status = $BackendPre->Run();
                     if ( !$Status{Success} ) {
 
@@ -152,7 +137,7 @@ sub Run {
             $Content = ${ $Content || \'' };
         }
         else {
-            my $FormID      = $ParamObject->GetParam( Param => 'FormID' ) || '';
+            my $FormID = $ParamObject->GetParam( Param => 'FormID' ) || '';
             my %UploadStuff = $ParamObject->GetUploadAll(
                 Param => 'FileUpload',
             );
@@ -343,7 +328,7 @@ sub Run {
                             @{
                                 $ProcessData->{ActivityDialogs}->{$ActivityDialogEntityID}
                                     ->{Config}->{Interface}
-                            }
+                                }
                         ),
                         %{ $ProcessData->{ActivityDialogs}->{$ActivityDialogEntityID} },
                     },
@@ -678,7 +663,7 @@ sub Run {
                         @{
                             $ProcessData->{Process}->{Config}->{Path}->{$Activity}->{$Transition}
                                 ->{TransitionAction}
-                        }
+                            }
                     );
                     if ($TransitionActionString) {
                         $TransitionActionString = '(' . $TransitionActionString . ')';
@@ -761,7 +746,7 @@ sub Run {
         }
 
         # check if Inactive state estity exists
-        my $StateList   = $StateObject->StateList( UserID => $Self->{UserID} );
+        my $StateList = $StateObject->StateList( UserID => $Self->{UserID} );
         my %StateLookup = reverse %{$StateList};
 
         my $StateEntityID = $StateLookup{'Inactive'};
@@ -1082,7 +1067,11 @@ sub Run {
             );
         }
 
-        if ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' ) {
+        if (
+            defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
+            && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
+            )
+        {
 
             # if the user would like to continue editing the process, just redirect to the edit screen
             return $LayoutObject->Redirect(
@@ -1672,7 +1661,7 @@ sub _ShowOverview {
                 Data => {
                     %{$ProcessData},
                     Description => $ProcessData->{Config}->{Description},
-                }
+                    }
             );
         }
     }
@@ -1798,9 +1787,9 @@ sub _ShowEdit {
     }
 
     $Param{StateSelection} = $LayoutObject->BuildSelection(
-        Data       => $StateList || {},
-        Name       => 'StateEntityID',
-        ID         => 'StateEntityID',
+        Data => $StateList || {},
+        Name => 'StateEntityID',
+        ID   => 'StateEntityID',
         SelectedID => $ProcessData->{StateEntityID}
             || $InactiveStateID,    # select inactive by default
         Sort        => 'AlphanumericKey',
@@ -1825,36 +1814,21 @@ sub _ShowEdit {
         ResultType => 'HASH',
         UserID     => $Self->{UserID},
     );
-    my $ProcessConfigJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessDump->{Process},
-    );
-    my $ActivityConfigJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessDump->{Activity},
-    );
-    my $ActivityDialogConfigJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessDump->{ActivityDialog},
-    );
-    my $TransitionConfigJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessDump->{Transition},
-    );
-    my $TransitionActionConfigJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessDump->{TransitionAction},
-    );
 
-    my $ProcessLayoutJSON = $LayoutObject->JSONEncode(
-        Data => $ProcessData->{Layout},
-    );
-
-    $LayoutObject->Block(
-        Name => 'ConfigSet',
-        Data => {
-            ProcessConfig          => $ProcessConfigJSON,
-            ProcessLayout          => $ProcessLayoutJSON,
-            ActivityConfig         => $ActivityConfigJSON,
-            ActivityDialogConfig   => $ActivityDialogConfigJSON,
-            TransitionConfig       => $TransitionConfigJSON,
-            TransitionActionConfig => $TransitionActionConfigJSON,
-        },
+    # send data to JS
+    $LayoutObject->AddJSData(
+        Key   => 'ConfigProcess',
+        Value => {
+            Process           => $ProcessDump->{Process},
+            ProcessLayout     => $ProcessData->{Layout},
+            Activity          => $ProcessDump->{Activity},
+            ActivityDialog    => $ProcessDump->{ActivityDialog},
+            Transition        => $ProcessDump->{Transition},
+            TransitionAction  => $ProcessDump->{TransitionAction},
+            PopupPathActivity => $LayoutObject->{Baselink}
+                . 'Action=AdminProcessManagementActivity;Subaction=ActivityEdit;',
+            PopupPathPath => $LayoutObject->{Baselink} . 'Action=AdminProcessManagementPath;Subaction=PathEdit;',
+            }
     );
 
     $Output .= $LayoutObject->Output(
@@ -1905,6 +1879,7 @@ sub _GetParams {
 sub _CheckProcessDelete {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     # get Process data
@@ -2061,7 +2036,7 @@ sub _PushSessionScreen {
 
     # add screen to the screen path
     push @{ $Self->{ScreensPath} }, {
-        Action    => $Self->{Action} || '',
+        Action => $Self->{Action} || '',
         Subaction => $Param{Subaction},
         ID        => $Param{ID},
         EntityID  => $Param{EntityID},
@@ -2082,19 +2057,15 @@ sub _PushSessionScreen {
     return 1;
 }
 
-sub _GetFullProcessConfig {
-    my ( $Self, %Param );
-
-}
-
 sub _GetProcessData {
 
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
     my %ProcessData;
 
+    # get needed objects
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # get process data
     my $Process = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Process')->ProcessGet(
         ID     => $Param{ID},
