@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminSMIME;
@@ -37,7 +37,7 @@ sub Run {
     # ------------------------------------------------------------ #
     if ( !$Kernel::OM->Get('Kernel::Config')->Get('SMIME') ) {
 
-        my $Output .= $LayoutObject->Header();
+        my $Output = $LayoutObject->Header();
         $Output .= $LayoutObject->NavigationBar();
 
         $LayoutObject->Block( Name => 'Overview' );
@@ -65,7 +65,7 @@ sub Run {
 
         $Output .= $LayoutObject->Notify(
             Priority => 'Error',
-            Data     => Translatable("S/MIME environment is not working. Please check log for more info!"),
+            Info     => Translatable("S/MIME environment is not working. Please check log for more info!"),
             Link     => $LayoutObject->{Baselink} . 'Action=AdminLog',
         );
 
@@ -104,6 +104,8 @@ sub Run {
         Value     => $Param{Search},
     );
 
+    $Param{Action} = $Self->{Subaction};
+
     # ------------------------------------------------------------ #
     # delete cert
     # ------------------------------------------------------------ #
@@ -132,7 +134,7 @@ sub Run {
         # remove certificate and private key if exists
         else {
             my $Certificate = $SMIMEObject->CertificateGet( Filename => $Filename );
-            my %Attributes  = $SMIMEObject->CertificateAttributes(
+            my %Attributes = $SMIMEObject->CertificateAttributes(
                 Certificate => $Certificate,
             );
 
@@ -194,7 +196,7 @@ sub Run {
     # show add certificate form
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ShowAddCertificate' ) {
-        $Self->_MaskAdd(
+        return $Self->_MaskAdd(
             Type => 'Certificate',
             %Param,
         );
@@ -342,7 +344,7 @@ sub Run {
         $Hash =~ s{(.+)\.\d}{$1}xms;
 
         my $Certificate = $SMIMEObject->CertificateGet( Filename => $Filename );
-        my %Attributes  = $SMIMEObject->CertificateAttributes( Certificate => $Certificate );
+        my %Attributes = $SMIMEObject->CertificateAttributes( Certificate => $Certificate );
         return $LayoutObject->Attachment(
             ContentType => 'text/plain',
             Content     => $Attributes{Fingerprint},
@@ -394,7 +396,7 @@ sub Run {
 
         # look for needed parameters
         my $CertFingerprint = $ParamObject->GetParam( Param => 'Fingerprint' ) || '';
-        my $Output          = $Self->_SignerCertificateOverview( CertFingerprint => $CertFingerprint );
+        my $Output = $Self->_SignerCertificateOverview( CertFingerprint => $CertFingerprint );
 
         return $Output;
     }
@@ -573,6 +575,7 @@ sub Run {
         $Output .= $LayoutObject->Footer();
         return $Output;
     }
+    return;
 }
 
 sub _MaskAdd {
@@ -581,7 +584,12 @@ sub _MaskAdd {
     # get layout object
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    $LayoutObject->Block( Name => 'Overview' );
+    $LayoutObject->Block(
+        Name => 'Overview',
+        Data => {
+            Action => $Param{Action}
+        },
+    );
     $LayoutObject->Block( Name => 'ActionList' );
     $LayoutObject->Block( Name => 'ActionOverview' );
 
@@ -722,8 +730,10 @@ sub _SignerCertificateOverview {
     # and is not equal to the actual Certificate Fingerprint
     my @ShowCertList;
     my %RelatedCerts = map { $_->{Fingerprint} => 1 } @RelatedCerts;
-    @ShowCertList = grep ( !defined $RelatedCerts{ $_->{Fingerprint} }
-            && $_->{Fingerprint} ne $Param{CertFingerprint}, @AvailableCerts );
+    @ShowCertList = grep {
+        !defined $RelatedCerts{ $_->{Fingerprint} }
+            && $_->{Fingerprint} ne $Param{CertFingerprint}
+    } @AvailableCerts;
 
     $LayoutObject->Block( Name => 'Overview' );
     $LayoutObject->Block( Name => 'ActionList' );
@@ -786,7 +796,7 @@ sub _SignerCertificateOverview {
         TemplateFile => 'AdminSMIME',
         Data         => {
             %Param,
-            Subtitle => 'Handle Private Certificate Relations',
+            Subtitle => Translatable('Handle Private Certificate Relations'),
         },
     );
     $Output .= $LayoutObject->Footer();
@@ -830,4 +840,5 @@ sub _CertificateRead {
     return $Output;
 
 }
+
 1;
