@@ -39,6 +39,11 @@ sub Run {
         $MainMenuConfigKey = 'AgentCustomerInformationCenter::MainMenu';
         $UserSettingsKey   = 'UserCustomerInformationCenter';
     }
+    elsif ( $Self->{Action} eq 'AgentCustomerUserInformationCenter' ) {
+        $BackendConfigKey  = 'AgentCustomerUserInformationCenter::Backend';
+        $MainMenuConfigKey = 'AgentCustomerUserInformationCenter::MainMenu';
+        $UserSettingsKey   = 'UserCustomerUserInformationCenter';
+    }
 
     # get needed objects
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
@@ -54,6 +59,7 @@ sub Run {
 
     # Get all configured statistics from the system that should be shown as a dashboard widget
     #   and register them dynamically in the configuration.
+    my @StatsIDs;
     if ( $Self->{Action} eq 'AgentDashboard' ) {
 
         my $StatsHash = $Kernel::OM->Get('Kernel::System::Stats')->StatsListGet(
@@ -96,7 +102,14 @@ sub Run {
                     'Description' => $Description,
                     'Group'       => $StatsPermissionGroups,
                 };
+                push @StatsIDs, $StatID;
             }
+
+            # send data to JS
+            $LayoutObject->AddJSData(
+                Key   => 'DashboardStatsIDs',
+                Value => \@StatsIDs
+            );
         }
     }
 
@@ -110,12 +123,33 @@ sub Run {
         # check CustomerID presence for all subactions that need it
         if ( $Self->{Subaction} ne 'UpdatePosition' ) {
             if ( !$Self->{CustomerID} ) {
+
+                $LayoutObject->AddJSOnDocumentComplete(
+                    Code => 'Core.Agent.CustomerInformationCenterSearch.OpenSearchDialog();'
+                );
+
                 my $Output = $LayoutObject->Header();
                 $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Output(
-                    TemplateFile => 'AgentCustomerInformationCenterBlank',
-                    Data         => \%Param,
+                $Output .= $LayoutObject->Footer();
+                return $Output;
+            }
+        }
+    }
+    elsif ( $Self->{Action} eq 'AgentCustomerUserInformationCenter' ) {
+
+        $Self->{CustomerUserID} = $ParamObject->GetParam( Param => 'CustomerUserID' );
+
+        # check CustomerUserID presence for all subactions that need it
+        if ( $Self->{Subaction} ne 'UpdatePosition' ) {
+
+            if ( !$Self->{CustomerUserID} ) {
+
+                $LayoutObject->AddJSOnDocumentComplete(
+                    Code => 'Core.Agent.CustomerUserInformationCenterSearch.OpenSearchDialog();'
                 );
+
+                my $Output = $LayoutObject->Header();
+                $Output .= $LayoutObject->NavigationBar();
                 $Output .= $LayoutObject->Footer();
                 return $Output;
             }
@@ -136,6 +170,14 @@ sub Run {
         my $Name = $ParamObject->GetParam( Param => 'Name' );
         my $Key = $UserSettingsKey . $Name;
 
+        # Mandatory widgets can't be removed.
+        if ( $Config->{$Name} && $Config->{$Name}->{Mandatory} ) {
+
+            return $LayoutObject->Redirect(
+                OP => "Action=$Self->{Action}",
+            );
+        }
+
         # update session
         $SessionObject->UpdateSessionID(
             SessionID => $Self->{SessionID},
@@ -156,6 +198,9 @@ sub Run {
         if ( $Self->{CustomerID} ) {
             $URL .= ";CustomerID=" . $LayoutObject->LinkEncode( $Self->{CustomerID} );
         }
+        if ( $Self->{CustomerUserID} ) {
+            $URL .= ";CustomerUserID=" . $LayoutObject->LinkEncode( $Self->{CustomerUserID} );
+        }
 
         return $LayoutObject->Redirect(
             OP => $URL,
@@ -242,6 +287,12 @@ sub Run {
                 $Active = 1;
                 last BACKEND;
             }
+
+            # Mandatory widgets can not be removed.
+            if ( $Config->{$Name}->{Mandatory} ) {
+                $Active = 1;
+            }
+
             my $Key = $UserSettingsKey . $Name;
 
             # update session
@@ -265,6 +316,9 @@ sub Run {
         if ( $Self->{CustomerID} ) {
             $URL .= ";CustomerID=" . $LayoutObject->LinkEncode( $Self->{CustomerID} );
         }
+        if ( $Self->{CustomerUserID} ) {
+            $URL .= ";CustomerUserID=" . $LayoutObject->LinkEncode( $Self->{CustomerUserID} );
+        }
 
         return $LayoutObject->Redirect(
             OP => $URL,
@@ -455,6 +509,18 @@ sub Run {
             $ContentBlockData{CustomerIDTitle} = "$CustomerCompanyData{CustomerCompanyName} ($Self->{CustomerID})";
         }
     }
+    elsif ( $Self->{Action} eq 'AgentCustomerUserInformationCenter' ) {
+
+        my %CustomerUserData = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerUserDataGet(
+            User => $Self->{CustomerUserID},
+        );
+
+        $ContentBlockData{CustomerUserID} = $Self->{CustomerUserID};
+
+        # H1 title
+        $ContentBlockData{CustomerUserIDTitle} = "\"$CustomerUserData{UserFullname}\" <$CustomerUserData{UserEmail}>";
+
+    }
 
     # show dashboard
     $LayoutObject->Block(
@@ -462,6 +528,8 @@ sub Run {
         Data => \%ContentBlockData,
     );
 
+    my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
+
     # get shown backends
     my %Backends;
     BACKEND:
@@ -473,8 +541,12 @@ sub Run {
             my @Groups = split /;/, $Config->{$Name}->{Group};
             GROUP:
             for my $Group (@Groups) {
-                my $Permission = 'UserIsGroupRo[' . $Group . ']';
-                if ( defined $Self->{$Permission} && $Self->{$Permission} eq 'Yes' ) {
+                my $HasPermission = $GroupObject->PermissionCheck(
+                    UserID    => $Self->{UserID},
+                    GroupName => $Group,
+                    Type      => 'ro',
+                );
+                if ($HasPermission) {
                     $PermissionOK = 1;
                     last GROUP;
                 }
@@ -489,6 +561,11 @@ sub Run {
         else {
             $Backends{$Name} = $Config->{$Name}->{Default};
         }
+
+        # Always show widgets with mandatory flag.
+        if ( $Config->{$Name}->{Mandatory} ) {
+            $Backends{$Name} = $Config->{$Name}->{Mandatory};
+        }
     }
 
     # set order of plugins
@@ -525,6 +602,7 @@ sub Run {
     my $Columns = $Self->{Config}->{DefaultColumns} || $ConfigObject->Get('DefaultOverviewColumns') || {};
 
     # try every backend to load and execute it
+    my @ContainerNames;
     NAME:
     for my $Name (@Order) {
 
@@ -540,15 +618,23 @@ sub Run {
         my $NameForm = $Name;
         $NameForm =~ s{-}{}g;
 
+        my %JSData = (
+            Name     => $Name,
+            NameForm => $NameForm,
+        );
+
+        push @ContainerNames, \%JSData;
+
         # rendering
         $LayoutObject->Block(
             Name => $Element{Config}->{Block},
             Data => {
                 %{ $Element{Config} },
-                Name       => $Name,
-                NameForm   => $NameForm,
-                Content    => ${ $Element{Content} },
-                CustomerID => $Self->{CustomerID} || '',
+                Name           => $Name,
+                NameForm       => $NameForm,
+                Content        => ${ $Element{Content} },
+                CustomerID     => $Self->{CustomerID} || '',
+                CustomerUserID => $Self->{CustomerUserID} || '',
             },
         );
 
@@ -558,6 +644,15 @@ sub Run {
             my $NameHTML = $Name;
             $NameHTML =~ s{-}{_}xmsg;
 
+            # send data to JS
+            $LayoutObject->AddJSData(
+                Key   => 'CanRefresh-' . $Name,
+                Value => {
+                    Name     => $Name,
+                    NameHTML => $NameHTML,
+                    }
+            );
+
             $LayoutObject->Block(
                 Name => $Element{Config}->{Block} . 'Refresh',
                 Data => {
@@ -568,10 +663,24 @@ sub Run {
             );
         }
 
+        # Do not show the delete link if the widget is mandatory.
+        if ( !$Config->{$Name}->{Mandatory} ) {
+
+            $LayoutObject->Block(
+                Name => $Element{Config}->{Block} . 'Remove',
+                Data => {
+                    %{ $Element{Config} },
+                    Name           => $Name,
+                    CustomerID     => $Self->{CustomerID} || '',
+                    CustomerUserID => $Self->{CustomerUserID} || '',
+                },
+            );
+        }
+
         # if column is not a default column, add it for translation
-        for my $Column ( sort keys %{ $Element{Config}{DefaultColumns} } ) {
+        for my $Column ( sort keys %{ $Element{Config}->{DefaultColumns} } ) {
             if ( !defined $Columns->{$Column} ) {
-                $Columns->{$Column} = $Element{Config}{DefaultColumns}{$Column}
+                $Columns->{$Column} = $Element{Config}->{DefaultColumns}->{$Column}
             }
         }
 
@@ -635,6 +744,12 @@ sub Run {
         }
     }
 
+    # send data to JS
+    $LayoutObject->AddJSData(
+        Key   => 'ContainerNames',
+        Value => \@ContainerNames,
+    );
+
     # build main menu
     my $MainMenuConfig = $ConfigObject->Get($MainMenuConfigKey);
     if ( IsHashRefWithData($MainMenuConfig) ) {
@@ -646,7 +761,8 @@ sub Run {
                 Name => 'MainMenuItem',
                 Data => {
                     %{ $MainMenuConfig->{$MainMenuItem} },
-                    CustomerID => $Self->{CustomerID},
+                    CustomerID     => $Self->{CustomerID},
+                    CustomerUserID => $Self->{CustomerUserID},
                 },
             );
         }
@@ -678,22 +794,24 @@ sub Run {
                 $TranslatedWord = Translatable('Pending till');
             }
             elsif ( $Column eq 'CustomerCompanyName' ) {
-                $TranslatedWord = Translatable('Customer Company Name');
+                $TranslatedWord = Translatable('Customer Name');
+            }
+            elsif ( $Column eq 'CustomerID' ) {
+                $TranslatedWord = Translatable('Customer ID');
+            }
+            elsif ( $Column eq 'CustomerName' ) {
+                $TranslatedWord = Translatable('Customer User Name');
             }
             elsif ( $Column eq 'CustomerUserID' ) {
                 $TranslatedWord = Translatable('Customer User ID');
             }
 
-            $LayoutObject->Block(
-                Name => 'ColumnTranslation',
-                Data => {
-                    ColumnName      => $Column,
-                    TranslateString => $TranslatedWord,
-                },
-            );
-            $LayoutObject->Block(
-                Name => 'ColumnTranslationSeparator',
+            # send data to JS
+            $LayoutObject->AddJSData(
+                Key   => 'Column' . $Column,
+                Value => $LayoutObject->{LanguageObject}->Translate($TranslatedWord),
             );
+
         }
     }
 
@@ -714,19 +832,11 @@ sub Run {
 
             $Counter++;
 
-            $LayoutObject->Block(
-                Name => 'ColumnTranslation',
-                Data => {
-                    ColumnName      => 'DynamicField_' . $DynamicField->{Name},
-                    TranslateString => $DynamicField->{Label},
-                },
+            # send data to JS
+            $LayoutObject->AddJSData(
+                Key   => 'ColumnDynamicField_' . $DynamicField->{Name},
+                Value => $LayoutObject->{LanguageObject}->Translate( $DynamicField->{Label} ),
             );
-
-            if ( $Counter < scalar @{$ColumnsDynamicField} ) {
-                $LayoutObject->Block(
-                    Name => 'ColumnTranslationSeparator',
-                );
-            }
         }
     }
 
@@ -752,14 +862,20 @@ sub _Element {
     my $GetColumnFilter       = $Param{GetColumnFilter};
     my $GetColumnFilterSelect = $Param{GetColumnFilterSelect};
 
+    my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
+
     # check permissions
     if ( $Configs->{$Name}->{Group} ) {
         my $PermissionOK = 0;
         my @Groups = split /;/, $Configs->{$Name}->{Group};
         GROUP:
         for my $Group (@Groups) {
-            my $Permission = 'UserIsGroupRo[' . $Group . ']';
-            if ( defined $Self->{$Permission} && $Self->{$Permission} eq 'Yes' ) {
+            my $HasPermission = $GroupObject->PermissionCheck(
+                UserID    => $Self->{UserID},
+                GroupName => $Group,
+                Type      => 'ro',
+            );
+            if ($HasPermission) {
                 $PermissionOK = 1;
                 last GROUP;
             }
@@ -778,12 +894,12 @@ sub _Element {
         Config                => $Configs->{$Name},
         Name                  => $Name,
         CustomerID            => $Self->{CustomerID} || '',
+        CustomerUserID        => $Self->{CustomerUserID} || '',
         SortBy                => $SortBy,
         OrderBy               => $OrderBy,
         ColumnFilter          => $ColumnFilter,
         GetColumnFilter       => $GetColumnFilter,
         GetColumnFilterSelect => $GetColumnFilterSelect,
-
     );
 
     # get module config
@@ -801,10 +917,11 @@ sub _Element {
 
     if ( $Param{FilterContentOnly} ) {
         my $FilterContent = $Object->FilterContent(
-            FilterColumn => $Param{FilterColumn},
-            Config       => $Configs->{$Name},
-            Name         => $Name,
-            CustomerID   => $Self->{CustomerID} || '',
+            FilterColumn   => $Param{FilterColumn},
+            Config         => $Configs->{$Name},
+            Name           => $Name,
+            CustomerID     => $Self->{CustomerID} || '',
+            CustomerUserID => $Self->{CustomerUserID} || '',
         );
         return $FilterContent;
     }
@@ -814,17 +931,27 @@ sub _Element {
     # add backend to settings selection
     if ($Backends) {
         my $Checked = '';
-        if ( $Backends->{$Name} ) {
+        if ( $Backends->{$Name} || $Configs->{$Name}->{Mandatory} ) {
             $Checked = 'checked="checked"';
         }
+
+        # Check whether the widget is forcibly displayed.
+        # Mandatory widgets are displayed as read-only.
+        my $Readonly = '';
+        if ( $Configs->{$Name}->{Mandatory} ) {
+            $Readonly = 'disabled="disabled"';
+        }
+
         $LayoutObject->Block(
             Name => 'ContentSettings',
             Data => {
                 %Config,
-                Name    => $Name,
-                Checked => $Checked,
+                Name     => $Name,
+                Checked  => $Checked,
+                Readonly => $Readonly,
             },
         );
+
         return if !$Backends->{$Name};
     }
 
@@ -835,7 +962,8 @@ sub _Element {
 
     if ( !$CacheKey ) {
         $CacheKey = $Name . '-'
-            . ( $Self->{CustomerID} || '' ) . '-'
+            . ( $Self->{CustomerID}     || '' ) . '-'
+            . ( $Self->{CustomerUserID} || '' ) . '-'
             . $LayoutObject->{UserLanguage};
     }
     if ( $Config{CacheTTL} ) {
@@ -850,8 +978,9 @@ sub _Element {
     if ( !defined $Content || $SortBy ) {
         $CacheUsed = 0;
         $Content   = $Object->Run(
-            AJAX       => $Param{AJAX},
-            CustomerID => $Self->{CustomerID} || '',
+            AJAX           => $Param{AJAX},
+            CustomerID     => $Self->{CustomerID} || '',
+            CustomerUserID => $Self->{CustomerUserID} || '',
         );
     }
 
