@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AgentTicketLockedView;
@@ -11,10 +11,10 @@ package Kernel::Modules::AgentTicketLockedView;
 use strict;
 use warnings;
 
-our $ObjectManagerDisabled = 1;
-
-use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
+
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -180,7 +180,7 @@ sub Run {
                 OwnerIDs   => [ $Self->{UserID} ],
                 OrderBy    => $OrderBy,
                 SortBy     => $SortByS,
-                UserID     => $Self->{UserID},
+                UserID     => 1,
                 Permission => 'ro',
             },
         },
@@ -196,7 +196,7 @@ sub Run {
                 TicketFlagUserID => $Self->{UserID},
                 OrderBy          => $OrderBy,
                 SortBy           => $SortByS,
-                UserID           => $Self->{UserID},
+                UserID           => 1,
                 Permission       => 'ro',
             },
         },
@@ -209,7 +209,7 @@ sub Run {
                 OwnerIDs   => [ $Self->{UserID} ],
                 OrderBy    => $OrderBy,
                 SortBy     => $SortByS,
-                UserID     => $Self->{UserID},
+                UserID     => 1,
                 Permission => 'ro',
             },
         },
@@ -223,7 +223,7 @@ sub Run {
                 OwnerIDs                      => [ $Self->{UserID} ],
                 OrderBy                       => $OrderBy,
                 SortBy                        => $SortByS,
-                UserID                        => $Self->{UserID},
+                UserID                        => 1,
                 Permission                    => 'ro',
             },
         },
@@ -242,7 +242,7 @@ sub Run {
     my $Limit = 10_000;
 
     my $ElementChanged = $ParamObject->GetParam( Param => 'ElementChanged' ) || '';
-    my $HeaderColumn   = $ElementChanged;
+    my $HeaderColumn = $ElementChanged;
     $HeaderColumn =~ s{\A ColumnFilter }{}msxg;
     my @OriginalViewableTickets;
     my @ViewableTickets;
@@ -330,7 +330,7 @@ sub Run {
             %{ $Filters{$Filter}->{Search} },
             %ColumnFilter,
             Result => 'COUNT',
-        );
+        ) || 0;
 
         $NavBarFilter{ $Filters{$Filter}->{Prio} } = {
             Count  => $Count,
@@ -347,7 +347,7 @@ sub Run {
         next COLUMNNAME if !$GetColumnFilter{$ColumnName};
         $ColumnFilterLink
             .= ';' . $LayoutObject->Ascii2Html( Text => 'ColumnFilter' . $ColumnName )
-            . '=' . $LayoutObject->Ascii2Html( Text => $GetColumnFilter{$ColumnName} );
+            . '=' . $LayoutObject->Ascii2Html( Text => $GetColumnFilter{$ColumnName} )
     }
 
     # show ticket's
@@ -389,7 +389,7 @@ sub Run {
 
         Filter     => $Filter,
         Filters    => \%NavBarFilter,
-        LinkFilter => $LinkFilter,
+        FilterLink => $LinkFilter,
 
         TitleName  => Translatable('My Locked Tickets'),
         TitleValue => $Filters{$Filter}->{Name},
