@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::ArticleCheck::PGP;
@@ -20,7 +20,7 @@ our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Crypt::PGP',
     'Kernel::System::Log',
-    'Kernel::System::Ticket',
+    'Kernel::System::Ticket::Article',
 );
 
 sub new {
@@ -57,17 +57,21 @@ sub Check {
     # check if pgp is enabled
     return if !$ConfigObject->Get('PGP');
 
-    # check if article is an email
-    return if $Param{Article}->{ArticleType} !~ /email/i;
+    my $ArticleObject = $Param{ArticleObject} || $Kernel::OM->Get('Kernel::System::Ticket::Article');
 
-    my $StoreDecryptedData = $ConfigObject->Get('PGP::StoreDecryptedData');
+    my $ArticleBackendObject = $ArticleObject->BackendForArticle(
+        TicketID  => $Param{Article}->{TicketID},
+        ArticleID => $Param{Article}->{ArticleID},
+    );
+
+    # check if article is an email
+    return if $ArticleBackendObject->ChannelNameGet() ne 'Email';
 
     # get needed objects
-    my $TicketObject = $Param{TicketObject} || $Kernel::OM->Get('Kernel::System::Ticket');
-    my $PGPObject    = $Kernel::OM->Get('Kernel::System::Crypt::PGP');
+    my $PGPObject = $Kernel::OM->Get('Kernel::System::Crypt::PGP');
 
     # check inline pgp crypt
-    if ( $Param{Article}->{Body} =~ /\A[\s\n]*^-----BEGIN PGP MESSAGE-----/m ) {
+    if ( $Param{Article}->{Body} && $Param{Article}->{Body} =~ /\A[\s\n]*^-----BEGIN PGP MESSAGE-----/m ) {
 
         # check sender (don't decrypt sent emails)
         if ( $Param{Article}->{SenderType} =~ /(agent|system)/i ) {
@@ -76,7 +80,7 @@ sub Check {
             return (
                 {
                     Key   => Translatable('Crypted'),
-                    Value => Translatable('Sent message crypted to recipient!'),
+                    Value => Translatable('Sent message encrypted to recipient!'),
                 }
             );
         }
@@ -87,70 +91,65 @@ sub Check {
             $Self->{Result} = \%Decrypt;
             $Param{Article}->{Body} = $Decrypt{Data};
 
-            if ($StoreDecryptedData) {
+            # updated article body
+            $ArticleBackendObject->ArticleUpdate(
+                TicketID  => $Param{Article}->{TicketID},
+                ArticleID => $Self->{ArticleID},
+                Key       => 'Body',
+                Value     => $Decrypt{Data},
+                UserID    => $Self->{UserID},
+            );
 
-                # updated article body
-                $TicketObject->ArticleUpdate(
-                    TicketID  => $Param{Article}->{TicketID},
-                    ArticleID => $Self->{ArticleID},
-                    Key       => 'Body',
-                    Value     => $Decrypt{Data},
-                    UserID    => $Self->{UserID},
-                );
+            # get a list of all article attachments
+            my %Index = $ArticleBackendObject->ArticleAttachmentIndex(
+                ArticleID => $Self->{ArticleID},
+            );
 
-                # get a list of all article attachments
-                my %Index = $TicketObject->ArticleAttachmentIndex(
-                    ArticleID => $Self->{ArticleID},
-                    UserID    => $Self->{UserID},
-                );
+            my @Attachments;
+            if ( IsHashRefWithData( \%Index ) ) {
+                for my $FileID ( sort keys %Index ) {
 
-                my @Attachments;
-                if ( IsHashRefWithData( \%Index ) ) {
-                    for my $FileID ( sort keys %Index ) {
-
-                        # get attachment details
-                        my %Attachment = $TicketObject->ArticleAttachment(
-                            ArticleID => $Self->{ArticleID},
-                            FileID    => $FileID,
-                            UserID    => $Self->{UserID},
-                        );
-
-                        # store attachemnts attributes that might change after decryption
-                        my $AttachmentContent  = $Attachment{Content};
-                        my $AttachmentFilename = $Attachment{Filename};
-
-                        # try to decrypt the attachment, non ecrypted attachments will succeed too.
-                        %Decrypt = $PGPObject->Decrypt( Message => $Attachment{Content} );
-
-                        if ( $Decrypt{Successful} ) {
-
-                            # set decrypted content
-                            $AttachmentContent = $Decrypt{Data};
-
-                            # remove .pgp .gpg or asc extensions (if any)
-                            $AttachmentFilename =~ s{ (\. [^\.]+) \. (?: pgp|gpg|asc) \z}{$1}msx;
-                        }
-
-                        # remember decrypted attachement, to add it later
-                        push @Attachments, {
-                            %Attachment,
-                            Content   => $AttachmentContent,
-                            Filename  => $AttachmentFilename,
-                            ArticleID => $Self->{ArticleID},
-                            UserID    => $Self->{UserID},
-                        };
-                    }
-
-                    # delete crypted attachments
-                    $TicketObject->ArticleDeleteAttachment(
+                    # get attachment details
+                    my %Attachment = $ArticleBackendObject->ArticleAttachment(
                         ArticleID => $Self->{ArticleID},
-                        UserID    => $Self->{UserID},
+                        FileID    => $FileID,
                     );
 
-                    # write decrypted attachments to the storage
-                    for my $Attachment (@Attachments) {
-                        $TicketObject->ArticleWriteAttachment( %{$Attachment} );
+                    # store attachemnts attributes that might change after decryption
+                    my $AttachmentContent  = $Attachment{Content};
+                    my $AttachmentFilename = $Attachment{Filename};
+
+                    # try to decrypt the attachment, non ecrypted attachments will succeed too.
+                    %Decrypt = $PGPObject->Decrypt( Message => $Attachment{Content} );
+
+                    if ( $Decrypt{Successful} ) {
+
+                        # set decrypted content
+                        $AttachmentContent = $Decrypt{Data};
+
+                        # remove .pgp .gpg or asc extensions (if any)
+                        $AttachmentFilename =~ s{ (\. [^\.]+) \. (?: pgp|gpg|asc) \z}{$1}msx;
                     }
+
+                    # remember decrypted attachement, to add it later
+                    push @Attachments, {
+                        %Attachment,
+                        Content   => $AttachmentContent,
+                        Filename  => $AttachmentFilename,
+                        ArticleID => $Self->{ArticleID},
+                        UserID    => $Self->{UserID},
+                    };
+                }
+
+                # delete crypted attachments
+                $ArticleBackendObject->ArticleDeleteAttachment(
+                    ArticleID => $Self->{ArticleID},
+                    UserID    => $Self->{UserID},
+                );
+
+                # write decrypted attachments to the storage
+                for my $Attachment (@Attachments) {
+                    $ArticleBackendObject->ArticleWriteAttachment( %{$Attachment} );
                 }
             }
 
@@ -177,10 +176,14 @@ sub Check {
     }
 
     # check inline pgp signature (but ignore if is in quoted text)
-    if ( $Param{Article}->{Body} =~ m{ ^\s* -----BEGIN [ ] PGP [ ] SIGNED [ ] MESSAGE----- }xms ) {
+    if (
+        $Param{Article}->{Body}
+        && $Param{Article}->{Body} =~ m{ ^\s* -----BEGIN [ ] PGP [ ] SIGNED [ ] MESSAGE----- }xms
+        )
+    {
 
         # get original message
-        my $Message = $TicketObject->ArticlePlain(
+        my $Message = $ArticleObject->ArticlePlain(
             ArticleID => $Self->{ArticleID},
             UserID    => $Self->{UserID},
         );
@@ -224,11 +227,13 @@ sub Check {
         # if crypted, decrypt it
         # remember that it was crypted!
 
-        # write email to fs
-        my $Message = $TicketObject->ArticlePlain(
+        # Get plain article/email from filesystem storage.
+        my $Message = $ArticleBackendObject->ArticlePlain(
             ArticleID => $Self->{ArticleID},
             UserID    => $Self->{UserID},
         );
+        return if !$Message;
+
         my $Parser = MIME::Parser->new();
         $Parser->decode_headers(0);
         $Parser->extract_nested_messages(0);
@@ -252,13 +257,13 @@ sub Check {
         {
 
             # check sender (don't decrypt sent emails)
-            if ( $Param{Article}->{SenderType} =~ /(agent|system)/i ) {
+            if ( $Param{Article}->{SenderType} && $Param{Article}->{SenderType} =~ /(agent|system)/i ) {
 
                 # return info
                 return (
                     {
                         Key        => Translatable('Crypted'),
-                        Value      => Translatable('Sent message crypted to recipient!'),
+                        Value      => Translatable('Sent message encrypted to recipient!'),
                         Successful => 1,
                     }
                 );
@@ -288,31 +293,28 @@ sub Check {
 
                 my $Body = $ParserObject->GetMessageBody();
 
-                if ($StoreDecryptedData) {
+                # updated article body
+                $ArticleBackendObject->ArticleUpdate(
+                    TicketID  => $Param{Article}->{TicketID},
+                    ArticleID => $Self->{ArticleID},
+                    Key       => 'Body',
+                    Value     => $Body,
+                    UserID    => $Self->{UserID},
+                );
 
-                    # updated article body
-                    $TicketObject->ArticleUpdate(
-                        TicketID  => $Param{Article}->{TicketID},
-                        ArticleID => $Self->{ArticleID},
-                        Key       => 'Body',
-                        Value     => $Body,
-                        UserID    => $Self->{UserID},
-                    );
+                # delete crypted attachments
+                $ArticleBackendObject->ArticleDeleteAttachment(
+                    ArticleID => $Self->{ArticleID},
+                    UserID    => $Self->{UserID},
+                );
 
-                    # delete crypted attachments
-                    $TicketObject->ArticleDeleteAttachment(
+                # write attachments to the storage
+                for my $Attachment ( $ParserObject->GetAttachments() ) {
+                    $ArticleBackendObject->ArticleWriteAttachment(
+                        %{$Attachment},
                         ArticleID => $Self->{ArticleID},
                         UserID    => $Self->{UserID},
                     );
-
-                    # write attachments to the storage
-                    for my $Attachment ( $ParserObject->GetAttachments() ) {
-                        $TicketObject->ArticleWriteAttachment(
-                            %{$Attachment},
-                            ArticleID => $Self->{ArticleID},
-                            UserID    => $Self->{UserID},
-                        );
-                    }
                 }
 
                 push(
