@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Layout::Popup;
@@ -17,17 +17,13 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::Output::HTML::Layout::Popup - CSS/JavaScript
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All valid functions.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item PopupClose()
+=head2 PopupClose()
 
 Generate a small HTML page which closes the pop-up window and
 executes an action in the main window.
@@ -67,34 +63,37 @@ sub PopupClose {
             $Param{URL} .= ';' . $Self->{SessionName} . '=' . $Self->{SessionID};
         }
 
-        $Self->Block(
-            Name => 'LoadParentURLAndClose',
-            Data => {
-                URL => $Param{URL},
-            },
+        # send data to JS
+        $Self->AddJSData(
+            Key   => 'PopupClose',
+            Value => 'LoadParentURLAndClose',
+        );
+        $Self->AddJSData(
+            Key   => 'PopupURL',
+            Value => $Param{URL},
         );
     }
     else {
-        $Self->Block(
-            Name => 'ReloadParentAndClose',
+
+        # send data to JS
+        $Self->AddJSData(
+            Key   => 'PopupClose',
+            Value => 'ReloadParentAndClose',
         );
     }
 
-    $Output .= $Self->Output( TemplateFile => 'AgentTicketActionPopupClose' );
     $Output .= $Self->Footer( Type => 'Small' );
     return $Output;
 }
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
