@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Daemon::DaemonModules::SchedulerTaskWorker;
@@ -15,34 +15,30 @@ use utf8;
 use File::Path qw();
 use Time::HiRes qw(sleep);
 
-use base qw(Kernel::System::Daemon::BaseDaemon);
+use parent qw(Kernel::System::Daemon::BaseDaemon);
 
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::DB',
     'Kernel::System::Daemon::SchedulerDB',
+    'Kernel::System::DateTime',
     'Kernel::System::Cache',
     'Kernel::System::Log',
     'Kernel::System::Main',
     'Kernel::System::Storable',
-    'Kernel::System::Time',
 );
 
 =head1 NAME
 
 Kernel::System::Daemon::DaemonModules::SchedulerTaskWorker - worker daemon for the scheduler
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 Scheduler worker daemon
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 Create scheduler task worker object.
 
@@ -58,11 +54,11 @@ sub new {
     # Get objects in constructor to save performance.
     $Self->{ConfigObject}      = $Kernel::OM->Get('Kernel::Config');
     $Self->{CacheObject}       = $Kernel::OM->Get('Kernel::System::Cache');
-    $Self->{TimeObject}        = $Kernel::OM->Get('Kernel::System::Time');
     $Self->{MainObject}        = $Kernel::OM->Get('Kernel::System::Main');
     $Self->{DBObject}          = $Kernel::OM->Get('Kernel::System::DB');
     $Self->{StorableObject}    = $Kernel::OM->Get('Kernel::System::Storable');
     $Self->{SchedulerDBObject} = $Kernel::OM->Get('Kernel::System::Daemon::SchedulerDB');
+    $Self->{DateTimeObject}    = $Kernel::OM->Create('Kernel::System::DateTime');
 
     # Disable in memory cache to be clusterable.
     $Self->{CacheObject}->Configure(
@@ -153,23 +149,8 @@ sub Run {
         # At the child, execute task.
         if ( !$PID ) {
 
-            # Define the ZZZ files.
-            my @ZZZFiles = (
-                'ZZZAAuto.pm',
-                'ZZZAuto.pm',
-            );
-
-            # Reload the ZZZ files.
-            for my $ZZZFile (@ZZZFiles) {
-
-                PREFIX:
-                for my $Prefix (@INC) {
-                    my $File = $Prefix . '/Kernel/Config/Files/' . $ZZZFile;
-                    next PREFIX if !-f $File;
-                    do $File;
-                    last PREFIX;
-                }
-            }
+            # Remove the ZZZAAuto.pm from %INC to force reloading it.
+            delete $INC{'Kernel/Config/Files/ZZZAAuto.pm'};
 
             # Destroy objects.
             $Kernel::OM->ObjectsDiscard(
@@ -254,7 +235,7 @@ sub Run {
             );
 
             # Force transactional events to run by discarding all objects before deleting the task.
-            $Kernel::OM->ObjectsDiscard();
+            $Kernel::OM->ObjectEventsHandle();
 
             $SchedulerDBObject->TaskDelete(
                 TaskID => $TaskID,
@@ -276,7 +257,7 @@ sub Run {
         $Self->{CurrentWorkers}->{$PID} = {
             PID       => $PID,
             TaskID    => $TaskID,
-            StartTime => $Self->{TimeObject}->SystemTime(),
+            StartTime => $Self->{DateTimeObject}->ToEpoch(),
         };
 
         $Self->{CurrentWorkersCount}++;
@@ -295,10 +276,6 @@ sub PostRun {
 
     $Self->{DiscardCount}--;
 
-    if ( $Self->{Debug} ) {
-        print "  $Self->{DaemonName} Discard Count: $Self->{DiscardCount}\n";
-    }
-
     # Update task locks and remove expired each 60 seconds.
     if ( !int $Self->{DiscardCount} % ( 60 / $Self->{SleepPost} ) ) {
 
@@ -319,6 +296,10 @@ sub PostRun {
     # Remove obsolete tasks before destroy.
     if ( $Self->{DiscardCount} == 0 ) {
         $Self->{SchedulerDBObject}->TaskCleanup();
+
+        if ( $Self->{Debug} ) {
+            print "  $Self->{DaemonName} will be stopped and set for restart!\n";
+        }
     }
 
     return if $Self->{DiscardCount} <= 0;
@@ -435,14 +416,12 @@ sub DESTROY {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
