@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::FileTemp;
@@ -21,22 +21,16 @@ our @ObjectDependencies = (
 
 Kernel::System::FileTemp - tmp files
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 This module is managing temporary files and directories.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
+=head2 new()
 
-=cut
+Don't use the constructor directly, use the ObjectManager instead:
 
-=item new()
-
-create an object. Do not use it directly, instead use:
-
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $FileTempObject = $Kernel::OM->Get('Kernel::System::FileTemp');
 
 =cut
@@ -53,7 +47,7 @@ sub new {
     return $Self;
 }
 
-=item TempFile()
+=head2 TempFile()
 
 returns an opened temporary file handle and its file name.
 Please note that you need to close the file handle for other processes to write to it.
@@ -81,7 +75,7 @@ sub TempFile {
     return ( $FH, $Filename );
 }
 
-=item TempDir()
+=head2 TempDir()
 
 returns a temp directory. The directory and its contents will be removed
 if the FileTemp object goes out of scope.
@@ -118,14 +112,12 @@ sub DESTROY {
 
 1;
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
