@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::GenericInterface::DebugLog;
@@ -23,22 +23,16 @@ our @ObjectDependencies = (
 
 Kernel::System::GenericInterface::DebugLog - log interface for generic interface
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All log functions.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 create a debug log object. Do not use it directly, instead use:
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $DebugLogObject = $Kernel::OM->Get('Kernel::System::GenericInterface::DebugLog');
 
 =cut
@@ -56,7 +50,7 @@ sub new {
     return $Self;
 }
 
-=item LogAdd()
+=head2 LogAdd()
 
 add a communication bit to database
 if we don't already have a communication chain, create it
@@ -201,7 +195,7 @@ sub LogAdd {
     return 1;
 }
 
-=item LogGet()
+=head2 LogGet()
 
 get communication chain data
 
@@ -286,7 +280,7 @@ sub LogGet {
     return \%LogData;
 }
 
-=item LogGetWithData()
+=head2 LogGetWithData()
 
 get all individual entries for a communication chain
 
@@ -347,7 +341,7 @@ sub LogGetWithData {
             SQL =>
                 'SELECT create_time, content, debug_level, subject'
                 . ' FROM gi_debugger_entry_content WHERE gi_debugger_entry_id = ?'
-                . ' ORDER BY create_time ASC',
+                . ' ORDER BY create_time ASC, id ASC',
             Bind => [ \$LogData->{LogID} ],
         )
         )
@@ -375,7 +369,7 @@ sub LogGetWithData {
     return $LogData;
 }
 
-=item LogDelete()
+=head2 LogDelete()
 
 delete a complete communication chain
 
@@ -517,7 +511,7 @@ sub LogDelete {
     return 1;
 }
 
-=item LogSearch()
+=head2 LogSearch()
 
 search for log chains based on several criteria
 when the parameter 'WithData' is set, the complete communication chains will be returned
@@ -531,6 +525,7 @@ when the parameter 'WithData' is set, the complete communication chains will be
         RemoteIP          => '192.168.0.1', # optional, must be valid IPv4 or IPv6 address
         WebserviceID      => 1, # optional
         WithData          => 0, # optional
+        Sort              => 'ASC', # optional. 'ASC' (default) or 'DESC'
     );
 
     $LogData = [
@@ -648,6 +643,18 @@ sub LogSearch {
         );
         return;
     }
+    if (
+        IsStringWithData( $Param{Sort} )
+        && $Param{Sort} ne 'ASC'
+        && $Param{Sort} ne 'DESC'
+        )
+    {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Sort must be 'DESC' or 'ASC'!",
+        );
+        return;
+    }
 
     # prepare db request
     my $SQL =
@@ -682,7 +689,8 @@ sub LogSearch {
         push @Bind, \$Param{CreatedAtOrBefore};
     }
 
-    $SQLExt .= ' ORDER BY create_time ASC';
+    my $SQLSort = IsStringWithData( $Param{Sort} ) ? $Param{Sort} : 'ASC';
+    $SQLExt .= ' ORDER BY create_time ' . $SQLSort;
 
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
@@ -732,11 +740,115 @@ sub LogSearch {
     return \@LogEntriesWithData;
 }
 
+=head2 LogCleanup()
+
+removes all log entries (including content) from a given time and before.
+
+returns 1 if successful or undef otherwise
+
+    my $Success = $DebugLogObject->LogCleanup(
+        CreatedAtOrBefore => '2011-12-31 23:59:59',
+    );
+
+=cut
+
+sub LogCleanup {
+    my ( $Self, %Param ) = @_;
+
+    if ( !$Param{CreatedAtOrBefore} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need CreatedAtOrBefore",
+        );
+
+        return;
+    }
+
+    if ( $Param{CreatedAtOrBefore} !~ m{ \A \d{4} - \d{2} - \d{2} [ ] \d{2} : \d{2} : \d{2} \z }xms ) {
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "CreatedAtOrBefore is not valid!",
+        );
+        return;
+    }
+
+    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
+    my $Success = $DateTimeObject->Set( String => $Param{CreatedAtOrBefore} );
+    if ( !$Success ) {
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "CreatedAtOrBefore is not valid!",
+        );
+        return;
+    }
+
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    # Get main debug log entries to delete
+    if (
+        !$DBObject->Prepare(
+            SQL  => 'SELECT id FROM gi_debugger_entry WHERE create_time <= ?',
+            Bind => [ \$Param{CreatedAtOrBefore} ],
+        )
+        )
+    {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Could not prepare db query!',
+        );
+        return;
+    }
+    my @LogEntryIDs;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+        push @LogEntryIDs, $Row[0];
+    }
+
+    return 1 if !@LogEntryIDs;
+
+    my $LogEntryIDsStr = join ',', @LogEntryIDs;
+
+    # Remove debug log entries contents.
+    if (
+        !$DBObject->Do(
+            SQL => "
+            DELETE FROM gi_debugger_entry_content
+            WHERE gi_debugger_entry_id in( $LogEntryIDsStr )",
+        )
+        )
+    {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Could not remove entries of communication chains in db!',
+        );
+        return;
+    }
+
+    # Remove debug log entries.
+    if (
+        !$DBObject->Do(
+            SQL => "
+            DELETE FROM gi_debugger_entry
+            WHERE id in( $LogEntryIDsStr )",
+        )
+        )
+    {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Could not remove communication chains in db!',
+        );
+        return;
+    }
+
+    return 1;
+}
+
 =begin Internal:
 
 =cut
 
-=item _LogAddChain()
+=head2 _LogAddChain()
 
 establish communication chain in database
 
@@ -837,14 +949,12 @@ sub _LogAddChain {
 
 =end Internal:
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
