@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Ticket::CustomerPermission::CustomerIDCheck;
@@ -58,21 +58,11 @@ sub Run {
     # get customer user object
     my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
 
-    # check customer id
-    my %CustomerData = $CustomerUserObject->CustomerUserDataGet(
-        User => $Param{UserID},
-    );
-
     # get customer ids
     my @CustomerIDs = $CustomerUserObject->CustomerIDs(
         User => $Param{UserID},
     );
 
-    # add own customer id
-    if ( $CustomerData{UserCustomerID} ) {
-        push @CustomerIDs, $CustomerData{UserCustomerID};
-    }
-
     # check customer ids, return access if customer id is the same
     CUSTOMERID:
     for my $CustomerID (@CustomerIDs) {
