@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Type;
@@ -24,22 +24,16 @@ our @ObjectDependencies = (
 
 Kernel::System::Type - type lib
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All type functions.
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=cut
-
-=item new()
+=head2 new()
 
 create an object
 
-    use Kernel::System::ObjectManager;
-    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $TypeObject = $Kernel::OM->Get('Kernel::System::Type');
 
 =cut
@@ -57,7 +51,7 @@ sub new {
     return $Self;
 }
 
-=item TypeAdd()
+=head2 TypeAdd()
 
 add a new ticket type
 
@@ -87,7 +81,7 @@ sub TypeAdd {
     if ( $Self->NameExistsCheck( Name => $Param{Name} ) ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A type with name '$Param{Name}' already exists!"
+            Message  => "A type with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -124,7 +118,7 @@ sub TypeAdd {
     return $ID;
 }
 
-=item TypeGet()
+=head2 TypeGet()
 
 get types attributes
 
@@ -236,7 +230,7 @@ sub TypeGet {
     return %Type;
 }
 
-=item TypeUpdate()
+=head2 TypeUpdate()
 
 update type attributes
 
@@ -273,7 +267,7 @@ sub TypeUpdate {
     {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "A type with name '$Param{Name}' already exists!"
+            Message  => "A type with the name '$Param{Name}' already exists.",
         );
         return;
     }
@@ -304,22 +298,6 @@ sub TypeUpdate {
         ],
     );
 
-    # check if the name of the default ticket type is updated
-    if (
-        $Kernel::OM->Get('Kernel::Config')->Get('Ticket::Type::Default') eq $Type{Name}
-        && $Type{Name} ne $Param{Name}
-        )
-    {
-
-        # update default ticket type SySConfig item
-        $Kernel::OM->Get('Kernel::System::SysConfig')->ConfigItemUpdate(
-            Valid => 1,
-            Key   => 'Ticket::Type::Default',
-            Value => $Param{Name}
-        );
-
-    }
-
     # reset cache
     $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => $Self->{CacheType},
@@ -328,7 +306,7 @@ sub TypeUpdate {
     return 1;
 }
 
-=item TypeList()
+=head2 TypeList()
 
 get type list
 
@@ -395,7 +373,7 @@ sub TypeList {
     return %TypeList;
 }
 
-=item TypeLookup()
+=head2 TypeLookup()
 
 get id or name for a ticket type
 
@@ -449,7 +427,7 @@ sub TypeLookup {
     return $ReturnData;
 }
 
-=item NameExistsCheck()
+=head2 NameExistsCheck()
 
     return 1 if another type with this name already exits
 
@@ -482,16 +460,15 @@ sub NameExistsCheck {
     }
     return 0;
 }
-1;
 
-=back
+1;
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
