@@ -1,19 +1,21 @@
 #!/usr/bin/perl -X
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU AFFERO General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# You should have received a copy of the GNU Affero General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
@@ -32,8 +34,7 @@ use Fcntl qw(:flock);
 
 use Kernel::System::ObjectManager;
 
-print STDOUT "otrs.Daemon.pl - the OTRS daemon\n";
-print STDOUT "Copyright (C) 2001-2019 OTRS AG, https://otrs.com/\n\n";
+print STDOUT "\nManage the OTRS daemon process.\n\n";
 
 local $Kernel::OM = Kernel::System::ObjectManager->new(
     'Kernel::System::Log' => {
@@ -62,7 +63,7 @@ if ( $NodeID !~ m{ \A \d+ \z }xms && $NodeID > 0 && $NodeID < 1000 ) {
 }
 
 # get pid directory
-my $PIDDir  = $ConfigObject->Get('Daemon::PID::Path') || $ConfigObject->Get('Home') . '/var/run/';
+my $PIDDir = $ConfigObject->Get('Daemon::PID::Path') || $ConfigObject->Get('Home') . '/var/run/';
 my $PIDFile = $PIDDir . "Daemon-NodeID-$NodeID.pid";
 my $PIDFH;
 
@@ -153,20 +154,24 @@ else {
 
 sub PrintUsage {
     my $UsageText = "Usage:\n";
-    $UsageText .= " otrs.Daemon.pl <ACTION> [--debug] [--force]\n";
+    $UsageText .= " otrs.Daemon.pl action [--debug] [--force]\n";
+    $UsageText .= "\nOptions:\n";
+    $UsageText .= sprintf " %-22s - %s", '[--debug]', 'Run the daemon in debug mode.' . "\n";
+    $UsageText .= sprintf " %-22s - %s", '[--force]',
+        'Reduce the time the main daemon waits other daemons to stop.' . "\n";
     $UsageText .= "\nActions:\n";
-    $UsageText .= sprintf " %-30s - %s", 'start', 'Starts the daemon process' . "\n";
-    $UsageText .= sprintf " %-30s - %s", 'stop', 'Stops the daemon process' . "\n";
-    $UsageText .= sprintf " %-30s - %s", 'status', 'Shows daemon process current state' . "\n";
-    $UsageText .= sprintf " %-30s - %s", 'help', 'Shows this help screen' . "\n";
-    $UsageText .= "\nNote:\n";
+    $UsageText .= sprintf " %-22s - %s", 'start', 'Start the daemon process.' . "\n";
+    $UsageText .= sprintf " %-22s - %s", 'stop', 'Stop the daemon process.' . "\n";
+    $UsageText .= sprintf " %-22s - %s", 'status', 'Show daemon process current state.' . "\n";
+    $UsageText .= sprintf " %-22s - %s", 'help', 'Display help for this command.' . "\n";
+    $UsageText .= "\nHelp:\n";
     $UsageText
-        .= " In debug mode if a daemon module is specified the debug mode will be activated only for that daemon.\n";
-    $UsageText .= " Debug information is stored in the daemon log files localed under: $LogDir\n";
+        .= "In debug mode if a daemon module is specified the debug mode will be activated only for that daemon.\n";
+    $UsageText .= "Debug information is stored in the daemon log files localed under: $LogDir\n";
     $UsageText .= "\n otrs.Daemon.pl start --debug SchedulerTaskWorker SchedulerCronTaskManager\n\n";
     $UsageText
-        .= "\n Forced stop reduces the time the main daemon waits other daemons to stop from normal 30 seconds to 5.\n";
-    $UsageText .= "\n otrs.Daemon.pl stop --force\n\n";
+        .= "Forced stop reduces the time the main daemon waits other daemons to stop from normal 30 seconds to 5.\n";
+    $UsageText .= "\n otrs.Daemon.pl stop --force\n";
     print STDOUT "$UsageText\n";
 
     return 1;
@@ -174,18 +179,18 @@ sub PrintUsage {
 
 sub Start {
 
-    # create a fork of the current process
-    # parent gets the PID of the child
-    # child gets PID = 0
+    # Create a fork of the current process.
+    #   Parent gets the PID of the child.
+    #   Child gets PID = 0.
     my $DaemonPID = fork;
 
-    # check if fork was not possible
+    # Check if fork was not possible.
     die "Can not create daemon process: $!" if !defined $DaemonPID || $DaemonPID < 0;
 
-    # close parent gracefully
+    # Close parent gracefully.
     exit 0 if $DaemonPID;
 
-    # lock PID
+    # Lock PID.
     my $LockSuccess = _PIDLock();
 
     if ( !$LockSuccess ) {
@@ -193,76 +198,73 @@ sub Start {
         exit 0;
     }
 
-    # get daemon modules from SysConfig
+    # Get daemon modules from SysConfig.
     my $DaemonModuleConfig = $Kernel::OM->Get('Kernel::Config')->Get('DaemonModules') || {};
 
-    # create daemon module hash
-    my %DaemonModules;
-    MODULE:
-    for my $Module ( sort keys %{$DaemonModuleConfig} ) {
-
-        next MODULE if !$Module;
-        next MODULE if !$DaemonModuleConfig->{$Module};
-        next MODULE if ref $DaemonModuleConfig->{$Module} ne 'HASH';
-        next MODULE if !$DaemonModuleConfig->{$Module}->{Module};
-
-        $DaemonModules{ $DaemonModuleConfig->{$Module}->{Module} } = {
-            PID  => 0,
-            Name => $Module,
-        };
-    }
+    # Create daemon module hash.
+    my %DaemonModules = _GetDaemonModules();
 
     my $DaemonChecker = 1;
-    local $SIG{INT}  = sub { $DaemonChecker = 0; };
-    local $SIG{TERM} = sub { $DaemonChecker = 0; $DaemonStopWait = 5; };
+    my $DaemonSuspend;
+    local $SIG{INT} = sub { $DaemonChecker = 0; $DaemonSuspend = 0; };
+    local $SIG{TERM} = sub { $DaemonChecker = 0; $DaemonStopWait = 5; $DaemonSuspend = 0; };
     local $SIG{CHLD} = "IGNORE";
+    local $SIG{HUP}  = sub {
+
+        # Stop current daemon run loop.
+        $DaemonSuspend = 1;
+
+        # Stop all daemon processes.
+        my %DaemonModulesCopy = %DaemonModules;
+        %DaemonModules = ();
+        _StopDaemonModules( DaemonModules => \%DaemonModulesCopy );
+
+        # Get all daemon modules using a refreshed configuration.
+        %DaemonModules = _GetDaemonModules();
+
+        # Continue the current daemon run.
+        $DaemonSuspend = 0;
+    };
 
     print STDOUT "Daemon started\n";
     if ($Debug) {
         print STDOUT "\nDebug information is stored in the daemon log files localed under: $LogDir\n\n";
     }
 
+    LOOP:
     while ($DaemonChecker) {
 
+        if ($DaemonSuspend) {
+            sleep .5;
+            next LOOP;
+        }
+
         MODULE:
         for my $Module ( sort keys %DaemonModules ) {
 
+            last MODULE if $DaemonSuspend;
             next MODULE if !$Module;
 
-            # check if daemon is still alive
+            # Check if daemon is still alive.
             if ( $DaemonModules{$Module}->{PID} && !kill 0, $DaemonModules{$Module}->{PID} ) {
                 $DaemonModules{$Module}->{PID} = 0;
             }
 
             next MODULE if $DaemonModules{$Module}->{PID};
 
-            # fork daemon process
+            # Fork daemon process.
             my $ChildPID = fork;
 
             if ( !$ChildPID ) {
 
                 my $ChildRun = 1;
+
                 local $SIG{INT}  = sub { $ChildRun = 0; };
                 local $SIG{TERM} = sub { $ChildRun = 0; };
                 local $SIG{CHLD} = "IGNORE";
 
-                # define the ZZZ files
-                my @ZZZFiles = (
-                    'ZZZAAuto.pm',
-                    'ZZZAuto.pm',
-                );
-
-                # reload the ZZZ files (mod_perl workaround)
-                for my $ZZZFile (@ZZZFiles) {
-
-                    PREFIX:
-                    for my $Prefix (@INC) {
-                        my $File = $Prefix . '/Kernel/Config/Files/' . $ZZZFile;
-                        next PREFIX if !-f $File;
-                        do $File;
-                        last PREFIX;
-                    }
-                }
+                # Remove the ZZZAAuto.pm from %INC to force reloading it.
+                delete $INC{'Kernel/Config/Files/ZZZAAuto.pm'};
 
                 local $Kernel::OM = Kernel::System::ObjectManager->new(
                     'Kernel::System::Log' => {
@@ -270,13 +272,13 @@ sub Start {
                     },
                 );
 
-                # disable in memory cache because many processes runs at the same time
+                # Disable in memory cache because many processes runs at the same time.
                 $Kernel::OM->Get('Kernel::System::Cache')->Configure(
                     CacheInMemory  => 0,
                     CacheInBackend => 1,
                 );
 
-                # set daemon log files
+                # Set daemon log files.
                 _LogFilesSet(
                     Module => $DaemonModules{$Module}->{Name}
                 );
@@ -285,7 +287,7 @@ sub Start {
                 LOOP:
                 while ($ChildRun) {
 
-                    # create daemon object if not exists
+                    # Create daemon object if not exists.
                     eval {
 
                         if (
@@ -303,7 +305,7 @@ sub Start {
                         $DaemonObject ||= $Kernel::OM->Get($Module);
                     };
 
-                    # wait 10 seconds if creation of object is not possible
+                    # Wait 10 seconds if creation of object is not possible.
                     if ( !$DaemonObject ) {
                         sleep 10;
                         last LOOP;
@@ -327,70 +329,15 @@ sub Start {
             }
         }
 
-        # sleep 0.1 seconds to protect the system of a 100% CPU usage if one daemon
-        # module is damaged and produces hard errors
+        # Sleep 0.1 seconds to protect the system of a 100% CPU usage if one daemon
+        #   module is damaged and produces hard errors.
         sleep 0.1;
     }
 
-    # send all daemon processes a stop signal
-    MODULE:
-    for my $Module ( sort keys %DaemonModules ) {
+    # Stop all daemon modules, first try soft otherwise hard.
+    _StopDaemonModules( DaemonModules => \%DaemonModules );
 
-        next MODULE if !$Module;
-        next MODULE if !$DaemonModules{$Module}->{PID};
-
-        if ($Debug) {
-            print STDOUT "Send stop signal to $Module with PID $DaemonModules{$Module}->{PID}\n";
-        }
-
-        kill 2, $DaemonModules{$Module}->{PID};
-    }
-
-    # wait for active daemon processes to stop (typically 30 secs, or just 5 if forced)
-    WAITTIME:
-    for my $WaitTime ( 1 .. $DaemonStopWait ) {
-
-        my $ProcessesStillRunning;
-        MODULE:
-        for my $Module ( sort keys %DaemonModules ) {
-
-            next MODULE if !$Module;
-            next MODULE if !$DaemonModules{$Module}->{PID};
-
-            # check if PID is still alive
-            if ( !kill 0, $DaemonModules{$Module}->{PID} ) {
-
-                # remove daemon pid from list
-                $DaemonModules{$Module}->{PID} = 0;
-            }
-            else {
-
-                $ProcessesStillRunning = 1;
-
-                if ($Debug) {
-                    print STDOUT "Waiting to stop $Module with PID $DaemonModules{$Module}->{PID}\n";
-                }
-            }
-        }
-
-        last WAITTIME if !$ProcessesStillRunning;
-
-        sleep 1;
-    }
-
-    # hard kill of all children witch are not stopped after 30 seconds
-    MODULE:
-    for my $Module ( sort keys %DaemonModules ) {
-
-        next MODULE if !$Module;
-        next MODULE if !$DaemonModules{$Module}->{PID};
-
-        print STDOUT "Killing $Module with PID $DaemonModules{$Module}->{PID}\n";
-
-        kill 9, $DaemonModules{$Module};
-    }
-
-    # remove current log files without content
+    # Remove current log files without content.
     _LogFilesCleanup();
 
     return 0;
@@ -405,12 +352,12 @@ sub Stop {
 
         if ($ForceStop) {
 
-            # send TERM signal to running daemon
+            # Send TERM signal to running daemon.
             kill 15, $RunningDaemonPID;
         }
         else {
 
-            # send INT signal to running daemon
+            # Send INT signal to running daemon.
             kill 2, $RunningDaemonPID;
         }
     }
@@ -544,23 +491,26 @@ sub _PIDUnlock {
 sub _LogFilesSet {
     my %Param = @_;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # define log file names
     my $FileStdOut = "$LogDir/$Param{Module}OUT";
     my $FileStdErr = "$LogDir/$Param{Module}ERR";
 
-    my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
+    my $SystemTime = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
 
-    # backup old log files
-    use File::Copy qw(move);
-    if ( -e "$FileStdOut.log" ) {
-        move( "$FileStdOut.log", "$FileStdOut-$SystemTime.log" );
+    # get log rotation type and backup old logs if logs should be rotated by OTRS
+    my $RotationType = lc $ConfigObject->Get('Daemon::Log::RotationType') || 'otrs';
+    if ( $RotationType eq 'otrs' ) {
+        use File::Copy qw(move);
+        if ( -e "$FileStdOut.log" ) {
+            move( "$FileStdOut.log", "$FileStdOut-$SystemTime.log" );
+        }
+        if ( -e "$FileStdErr.log" ) {
+            move( "$FileStdErr.log", "$FileStdErr-$SystemTime.log" );
+        }
     }
-    if ( -e "$FileStdErr.log" ) {
-        move( "$FileStdErr.log", "$FileStdErr-$SystemTime.log" );
-    }
-
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     my $RedirectSTDOUT = $ConfigObject->Get('Daemon::Log::STDOUT') || 0;
     my $RedirectSTDERR = $ConfigObject->Get('Daemon::Log::STDERR') || 0;
@@ -573,8 +523,10 @@ sub _LogFilesSet {
         open STDERR, '>>', "$FileStdErr.log";
     }
 
-    # remove not needed log files
-    my $DaysToKeep     = $ConfigObject->Get('Daemon::Log::DaysToKeep') || 1;
+    return 1 if $RotationType ne 'otrs';
+
+    # remove not needed log files if OTRS rotation is enabled
+    my $DaysToKeep = $ConfigObject->Get('Daemon::Log::DaysToKeep') || 1;
     my $DaysToKeepTime = $SystemTime - $DaysToKeep * 24 * 60 * 60;
 
     my @LogFiles = glob "$LogDir/*.log";
@@ -605,6 +557,10 @@ sub _LogFilesSet {
 sub _LogFilesCleanup {
     my %Param = @_;
 
+    # skip cleanup if OTRS log rotation is not enabled
+    my $RotationType = lc $Kernel::OM->Get('Kernel::Config')->Get('Daemon::Log::RotationType') || 'otrs';
+    return 1 if $RotationType ne 'otrs';
+
     my @LogFiles = glob "$LogDir/*.log";
 
     LOGFILE:
@@ -630,4 +586,99 @@ sub _LogFilesCleanup {
     return 1;
 }
 
+sub _GetDaemonModules {
+    my %Param = @_;
+
+    $Kernel::OM->ObjectsDiscard(
+        Objects => [ 'Kernel::Config', ],
+    );
+
+    # Get daemon modules from SysConfig.
+    my $DaemonModuleConfig = $Kernel::OM->Get('Kernel::Config')->Get('DaemonModules') || {};
+
+    # Create daemon module hash.
+    my %DaemonModules;
+    MODULE:
+    for my $Module ( sort keys %{$DaemonModuleConfig} ) {
+
+        next MODULE if !$Module;
+        next MODULE if !$DaemonModuleConfig->{$Module};
+        next MODULE if ref $DaemonModuleConfig->{$Module} ne 'HASH';
+        next MODULE if !$DaemonModuleConfig->{$Module}->{Module};
+
+        $DaemonModules{ $DaemonModuleConfig->{$Module}->{Module} } = {
+            PID  => 0,
+            Name => $Module,
+        };
+    }
+
+    return %DaemonModules;
+}
+
+sub _StopDaemonModules {
+    my %Param = @_;
+
+    my %DaemonModules = %{ $Param{DaemonModules} };
+
+    # Send all daemon processes a stop signal.
+    MODULE:
+    for my $Module ( sort keys %DaemonModules ) {
+
+        next MODULE if !$Module;
+        next MODULE if !$DaemonModules{$Module}->{PID};
+
+        if ($Debug) {
+            print STDOUT "Send stop signal to $Module with PID $DaemonModules{$Module}->{PID}\n";
+        }
+
+        kill 2, $DaemonModules{$Module}->{PID};
+    }
+
+    # Wait for active daemon processes to stop (typically 30 secs, or just 5 if forced).
+    WAITTIME:
+    for my $WaitTime ( 1 .. $DaemonStopWait ) {
+
+        my $ProcessesStillRunning;
+        MODULE:
+        for my $Module ( sort keys %DaemonModules ) {
+
+            next MODULE if !$Module;
+            next MODULE if !$DaemonModules{$Module}->{PID};
+
+            # Check if PID is still alive.
+            if ( !kill 0, $DaemonModules{$Module}->{PID} ) {
+
+                # Remove daemon pid from list.
+                $DaemonModules{$Module}->{PID} = 0;
+            }
+            else {
+
+                $ProcessesStillRunning = 1;
+
+                if ($Debug) {
+                    print STDOUT "Waiting to stop $Module with PID $DaemonModules{$Module}->{PID}\n";
+                }
+            }
+        }
+
+        last WAITTIME if !$ProcessesStillRunning;
+
+        sleep 1;
+    }
+
+    # Hard kill of all children witch are not stopped after 30 seconds.
+    MODULE:
+    for my $Module ( sort keys %DaemonModules ) {
+
+        next MODULE if !$Module;
+        next MODULE if !$DaemonModules{$Module}->{PID};
+
+        print STDOUT "Killing $Module with PID $DaemonModules{$Module}->{PID}\n";
+
+        kill 9, $DaemonModules{$Module}->{PID};
+    }
+
+    return 1;
+}
+
 exit 0;
