@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package scripts::test::ObjectManager::Dummy;    ## no critic
@@ -16,8 +16,8 @@ our @ObjectDependencies = ();                   # we want to use an undeclared d
 
 sub new {
     my ( $Class, %Param ) = @_;
-
     bless \%Param, $Class;
+    return \%Param;
 }
 
 sub Data {
@@ -30,6 +30,8 @@ sub DESTROY {
     # Request this object (undeclared dependency) in the desctructor.
     #   This will create it again in the OM to test that ObjectsDiscard will still work.
     $Kernel::OM->Get('scripts::test::ObjectManager::Dummy2');
+
+    return;
 }
 
 1;
