@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -29,11 +29,27 @@ Core.Agent.TicketProcess = (function (TargetNS) {
      */
     TargetNS.Init = function () {
 
-        $('#ProcessEntityID').bind('change', function () {
+        var ProcessID = Core.Config.Get('ProcessID');
+
+        if (typeof ProcessID !== 'undefined') {
+            $('#ProcessEntityID').val(ProcessID);
+        }
+
+        if (typeof Core.Config.Get('ParentReload') !== 'undefined' && parseInt(Core.Config.Get('ParentReload'), 10) === 1){
+            Core.UI.Popup.ExecuteInParentWindow(function(WindowObject) {
+                if (WindowObject.Core.UI.Popup.GetWindowMode() !== 'Iframe') {
+                    WindowObject.Core.UI.Popup.FirePopupEvent('Reload');
+                }
+            });
+        }
+
+        $('#ProcessEntityID').on('change', function () {
             var Data = {
                 Action: 'AgentTicketProcess',
                 Subaction: 'DisplayActivityDialogAJAX',
                 ProcessEntityID: $('#ProcessEntityID').val(),
+                LinkTicketID: $('#LinkTicketID').val(),
+                ArticleID: $('#ArticleID').val(),
                 FormID: $(this).closest('form').find('input:hidden[name=FormID]').val(),
                 IsAjaxRequest: 1,
                 IsMainWindow: 1
@@ -118,6 +134,9 @@ Core.Agent.TicketProcess = (function (TargetNS) {
                         // Register event for tree selection dialog
                         Core.UI.TreeSelection.InitTreeSelection();
 
+                        // initialize ajax dnd upload
+                        Core.UI.InitAjaxDnDUpload();
+
                         // move help triggers into field rows for dynamic fields
                         $('.Row > .FieldHelpContainer').each(function () {
                             if (!$(this).next('label').find('.Marker').length) {
@@ -136,9 +155,18 @@ Core.Agent.TicketProcess = (function (TargetNS) {
                             Core.App.Publish('Event.App.Responsive.SmallerOrEqualScreenL');
                         }
 
+                        // trigget customer auto complete event if field is accesible
+                        if ($ElementToUpdate.find('#CustomerAutoComplete').length) {
+                            Core.Agent.CustomerSearchAutoComplete.Init();
+                        }
+
                         $('#AJAXLoader').addClass('Hidden');
                         $('#AJAXDialog').val('1');
 
+                        Core.TicketProcess.Init();
+
+                        // Publish event when first activity dialog has loaded, so other code can know to execute again.
+                        Core.App.Publish('TicketProcess.Init.FirstActivityDialog.Load', [$ElementToUpdate]);
                     }
                     else {
 
@@ -155,7 +183,14 @@ Core.Agent.TicketProcess = (function (TargetNS) {
             }
             return false;
         });
+
+        // If process is pre-selected trigger change event on ProcessEntityID field.
+        if ($('#ProcessEntityID').val() !== "") {
+            $('#ProcessEntityID').trigger('change');
+        }
     };
 
+    Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
+
     return TargetNS;
 }(Core.Agent.TicketProcess || {}));
