@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -181,13 +181,13 @@ Core.Form.ErrorTooltips = (function (TargetNS) {
      *      This function initializes the tooltips on an input field.
      */
     TargetNS.InitTooltip = function ($Element, TooltipContent) {
-        $Element.unbind('focus.Tooltip');
-        $Element.bind('focus.Tooltip', function () {
+        $Element
+        .off('focus.Tooltip')
+        .on('focus.Tooltip', function () {
             TargetNS.ShowTooltip($Element, TooltipContent);
         });
 
-        $Element.unbind('blur.Tooltip');
-        $Element.bind('blur.Tooltip', TargetNS.HideTooltip);
+        $Element.off('blur.Tooltip').on('blur.Tooltip', TargetNS.HideTooltip);
     };
 
     /**
@@ -200,8 +200,8 @@ Core.Form.ErrorTooltips = (function (TargetNS) {
      */
     TargetNS.RemoveTooltip = function ($Element) {
         TargetNS.HideTooltip();
-        $Element.unbind('focus.Tooltip');
-        $Element.unbind('blur.Tooltip');
+        $Element.off('focus.Tooltip');
+        $Element.off('blur.Tooltip');
     };
 
     /**
